@@ -2,10 +2,7 @@
 # Copyright (c) 2023 Airbyte, Inc., all rights reserved.
 #
 
-from airbyte_cdk.sources.declarative.auth.oauth import DeclarativeOauth2Authenticator
 from airbyte_cdk.sources.declarative.auth.jwt import JwtAuthenticator
+from airbyte_cdk.sources.declarative.auth.oauth import DeclarativeOauth2Authenticator
 
-__all__ = [
-    "DeclarativeOauth2Authenticator",
-    "JwtAuthenticator"
-]
+__all__ = ["DeclarativeOauth2Authenticator", "JwtAuthenticator"]
