@@ -6,5 +6,16 @@ from airbyte_cdk.sources.declarative.extractors.dpath_extractor import DpathExtr
 from airbyte_cdk.sources.declarative.extractors.http_selector import HttpSelector
 from airbyte_cdk.sources.declarative.extractors.record_filter import RecordFilter
 from airbyte_cdk.sources.declarative.extractors.record_selector import RecordSelector
+from airbyte_cdk.sources.declarative.extractors.response_to_file_extractor import (
+    ResponseToFileExtractor,
+)
+from airbyte_cdk.sources.declarative.extractors.type_transformer import TypeTransformer
 
-__all__ = ["HttpSelector", "DpathExtractor", "RecordFilter", "RecordSelector"]
+__all__ = [
+    "TypeTransformer",
+    "HttpSelector",
+    "DpathExtractor",
+    "RecordFilter",
+    "RecordSelector",
+    "ResponseToFileExtractor",
+]
