@@ -8,7 +8,13 @@ from abc import ABC, abstractmethod
 from typing import Generic, Iterable, Optional
 
 from airbyte_cdk.connector import TConfig
-from airbyte_cdk.models import AirbyteCatalog, AirbyteMessage, AirbyteStateMessage, ConfiguredAirbyteCatalog, ConnectorSpecification
+from airbyte_cdk.models import (
+    AirbyteCatalog,
+    AirbyteMessage,
+    AirbyteStateMessage,
+    ConfiguredAirbyteCatalog,
+    ConnectorSpecification,
+)
 from airbyte_cdk.sources.source import Source
 
 
@@ -22,7 +28,12 @@ class SourceRunner(ABC, Generic[TConfig]):
         pass
 
     @abstractmethod
-    def read(self, config: TConfig, catalog: ConfiguredAirbyteCatalog, state: Optional[AirbyteStateMessage]) -> Iterable[AirbyteMessage]:
+    def read(
+        self,
+        config: TConfig,
+        catalog: ConfiguredAirbyteCatalog,
+        state: Optional[AirbyteStateMessage],
+    ) -> Iterable[AirbyteMessage]:
         pass
 
 
@@ -37,5 +48,10 @@ class CDKRunner(SourceRunner[TConfig]):
     def discover(self, config: TConfig) -> AirbyteCatalog:
         return self._source.discover(self._logger, config)
 
-    def read(self, config: TConfig, catalog: ConfiguredAirbyteCatalog, state: Optional[AirbyteStateMessage]) -> Iterable[AirbyteMessage]:
+    def read(
+        self,
+        config: TConfig,
+        catalog: ConfiguredAirbyteCatalog,
+        state: Optional[AirbyteStateMessage],
+    ) -> Iterable[AirbyteMessage]:
         return self._source.read(self._logger, config, catalog, state=[state] if state else [])
