@@ -1,4 +1,6 @@
-from airbyte_cdk.sources.file_based.schema_validation_policies.abstract_schema_validation_policy import AbstractSchemaValidationPolicy
+from airbyte_cdk.sources.file_based.schema_validation_policies.abstract_schema_validation_policy import (
+    AbstractSchemaValidationPolicy,
+)
 from airbyte_cdk.sources.file_based.schema_validation_policies.default_schema_validation_policies import (
     DEFAULT_SCHEMA_VALIDATION_POLICIES,
     EmitRecordPolicy,
