@@ -8,12 +8,11 @@ from .checkpoint_reader import (
     FullRefreshCheckpointReader,
     IncrementalCheckpointReader,
     LegacyCursorBasedCheckpointReader,
-    ResumableFullRefreshCheckpointReader
+    ResumableFullRefreshCheckpointReader,
 )
 from .cursor import Cursor
 from .resumable_full_refresh_cursor import ResumableFullRefreshCursor
 
-
 __all__ = [
     "CheckpointMode",
     "CheckpointReader",
@@ -23,5 +22,5 @@ __all__ = [
     "IncrementalCheckpointReader",
     "LegacyCursorBasedCheckpointReader",
     "ResumableFullRefreshCheckpointReader",
-    "ResumableFullRefreshCursor"
+    "ResumableFullRefreshCursor",
 ]
