@@ -5,14 +5,23 @@ from typing import List, Optional, Union
 from airbyte_cdk.sources.streams import Stream
 
 
-def get_primary_key_from_stream(stream_primary_key: Optional[Union[str, List[str], List[List[str]]]]) -> List[str]:
+def get_primary_key_from_stream(
+    stream_primary_key: Optional[Union[str, List[str], List[List[str]]]],
+) -> List[str]:
     if stream_primary_key is None:
         return []
     elif isinstance(stream_primary_key, str):
         return [stream_primary_key]
     elif isinstance(stream_primary_key, list):
-        if len(stream_primary_key) > 0 and all(isinstance(k, str) for k in stream_primary_key):
+        are_all_elements_str = all(isinstance(k, str) for k in stream_primary_key)
+        are_all_elements_list_of_size_one = all(
+            isinstance(k, list) and len(k) == 1 for k in stream_primary_key
+        )
+
+        if are_all_elements_str:
             return stream_primary_key  # type: ignore # We verified all items in the list are strings
+        elif are_all_elements_list_of_size_one:
+            return list(map(lambda x: x[0], stream_primary_key))
         else:
             raise ValueError(f"Nested primary keys are not supported. Found {stream_primary_key}")
     else:
@@ -22,7 +31,9 @@ def get_primary_key_from_stream(stream_primary_key: Optional[Union[str, List[str
 def get_cursor_field_from_stream(stream: Stream) -> Optional[str]:
     if isinstance(stream.cursor_field, list):
         if len(stream.cursor_field) > 1:
-            raise ValueError(f"Nested cursor fields are not supported. Got {stream.cursor_field} for {stream.name}")
+            raise ValueError(
+                f"Nested cursor fields are not supported. Got {stream.cursor_field} for {stream.name}"
+            )
         elif len(stream.cursor_field) == 0:
             return None
         else:
