@@ -8,7 +8,7 @@ from .error_handler import ErrorHandler
 from .error_message_parser import ErrorMessageParser
 from .http_status_error_handler import HttpStatusErrorHandler
 from .json_error_message_parser import JsonErrorMessageParser
-from .response_models import ResponseAction, ErrorResolution
+from .response_models import ErrorResolution, ResponseAction
 
 __all__ = [
     "BackoffStrategy",
@@ -18,5 +18,5 @@ __all__ = [
     "HttpStatusErrorHandler",
     "JsonErrorMessageParser",
     "ResponseAction",
-    "ErrorResolution"
+    "ErrorResolution",
 ]
