@@ -3,7 +3,13 @@
 import time
 from typing import Any, Optional
 
-from airbyte_cdk.models import AirbyteAnalyticsTraceMessage, AirbyteMessage, AirbyteTraceMessage, TraceType, Type
+from airbyte_cdk.models import (
+    AirbyteAnalyticsTraceMessage,
+    AirbyteMessage,
+    AirbyteTraceMessage,
+    TraceType,
+    Type,
+)
 
 
 def create_analytics_message(type: str, value: Optional[Any]) -> AirbyteMessage:
@@ -12,6 +18,8 @@ def create_analytics_message(type: str, value: Optional[Any]) -> AirbyteMessage:
         trace=AirbyteTraceMessage(
             type=TraceType.ANALYTICS,
             emitted_at=time.time() * 1000,
-            analytics=AirbyteAnalyticsTraceMessage(type=type, value=str(value) if value is not None else None),
+            analytics=AirbyteAnalyticsTraceMessage(
+                type=type, value=str(value) if value is not None else None
+            ),
         ),
     )
